summaryrefslogtreecommitdiff
path: root/include/dom/core/attr.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dom/core/attr.h')
-rw-r--r--include/dom/core/attr.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/dom/core/attr.h b/include/dom/core/attr.h
index 69612f7..1ae5be5 100644
--- a/include/dom/core/attr.h
+++ b/include/dom/core/attr.h
@@ -114,7 +114,7 @@ static inline dom_exception dom_attr_is_id(struct dom_attr *attr, bool *result)
* Following are our implementation specific APIs.
*
* These APIs are defined for the purpose that there are some attributes in
* HTML and other DOM module whose type is not DOMString, but unsigned long or
* boolean, for those types of attributes, clients should call one of the
* following APIs to set it.
*
@@ -135,8 +135,8 @@ static inline dom_exception dom_attr_is_id(struct dom_attr *attr, bool *result)
* dom_attr_get_* functions.
*/
dom_attr_type dom_attr_get_type(dom_attr *a);
-dom_exception dom_attr_get_integer(dom_attr *a, unsigned long *value);
-dom_exception dom_attr_set_integer(dom_attr *a, unsigned long value);
+dom_exception dom_attr_get_integer(dom_attr *a, uint32_t *value);
+dom_exception dom_attr_set_integer(dom_attr *a, uint32_t value);
dom_exception dom_attr_get_short(dom_attr *a, unsigned short *value);
dom_exception dom_attr_set_short(dom_attr *a, unsigned short value);
dom_exception dom_attr_get_bool(dom_attr *a, bool *value);
@@ -114,7 +114,7 @@ static inline dom_exception dom_attr_is_id(struct dom_attr *attr, bool *result)
*
* These APIs are defined for the purpose that there are some attributes in
- * HTML and other DOM module whose type is not DOMString, but unsigned long or
+ * HTML and other DOM module whose type is not DOMString, but uint32_t or
* boolean, for those types of attributes, clients should call one of the
* following APIs to set it.